part of flutter_kingmed_ui;
class MessageDialog {
  static show(BuildContext buildContext,
      MessageType type,
      String titleText,
      String contentText,
      {
        TextStyle? titleStyle,
        TextStyle? contentStyle,
        TextStyle? comfirmStyle,
        TextStyle? cancelStyle,
        VoidCallback? executeCall
      }) {

    showDialog(
        context: buildContext,
        builder: (context) {
          return AlertDialog(
            title: Row(
               children: [
                 Icon(
                   getTitleIcon(type),
                   color: getTitleColor(type),
                 ),
                 SizedBox(
                    width: 6,
                 ),
                 Text(titleText,style: titleStyle??TextStyle(
                     fontSize: 16,
                     color: Colors.black,
                     fontWeight: FontWeight.bold,
                     decoration: TextDecoration.none))
               ],
            ),
            content: Container(
              margin: EdgeInsets.fromLTRB(12, 0, 0, 0),
               child: Text(contentText,style: contentStyle??TextStyle(
                   fontSize: 14,
                   color: Colors.black87,
                   decoration: TextDecoration.none)),
            ),
            actions: <Widget>[

              TextButton(
                child: Text(
                  '取消',
                  style: cancelStyle ??
                      new TextStyle(
                          fontSize: 14,
                          color: Colors.black54,
                          decoration: TextDecoration.none),
                ),
                onPressed: () {
                  Navigator.pop(context);
                },
              ),

              TextButton(
                child: Text(
                  '确认',
                  style: comfirmStyle ??
                      new TextStyle(
                          fontSize: 14,
                          color: Colors.blueAccent,
                          fontWeight: FontWeight.bold,
                          decoration: TextDecoration.none),
                ),
                onPressed: () async {

                  if(executeCall!=null){
                    executeCall();
                  }
                  Navigator.of(context).pop();
                },
              ),

            ],
          );
        });
  }
}

Color getTitleColor(MessageType messageType){
  if(messageType == MessageType.success) {
    return Colors.blue;
  } else if (messageType == MessageType.warn) {
    return Colors.orange;
  } else if (messageType == MessageType.info) {
    return Colors.blue;
  } else if (messageType == MessageType.error) {
    return Colors.red;
  }
  return Colors.blue;
}

IconData getTitleIcon(MessageType messageType){
  if(messageType == MessageType.success) {
    return Icons.check_circle_outline_rounded;
  } else if (messageType == MessageType.warn) {
    return Icons.warning_amber_outlined;
  } else if (messageType == MessageType.info) {
    return Icons.info_outline_rounded;
  } else if (messageType == MessageType.error) {
    return Icons.error_outline_outlined;
  }
  return Icons.check_circle_outline_rounded;
}
