part of flutter_kingmed_ui;
class MessageSnackBar{

  static showMessage(
      BuildContext context, MessageType messageType, String content,
      {TextStyle textStyle=const TextStyle(fontSize: 14, color: Colors.white),
      double marginBottom = 12,
      int durationMilliseconds = 2500}) {

    ScaffoldMessenger.of(context).showSnackBar(SnackBar(
      margin: EdgeInsets.fromLTRB(12, 0, 12, marginBottom),
      behavior: SnackBarBehavior.floating,
      duration: Duration(milliseconds: durationMilliseconds),
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(4),
      ),
      elevation: 2,
      backgroundColor: getColor(messageType),
      content: Container(
        child: Row(
          children: <Widget>[
            Icon(
              getIcon(messageType),
              color: Colors.white,
            ),
            SizedBox(
              width: 12,
            ),
            Text(content, style: textStyle)
          ],
        ),
      ),
    ));
  }

}

Color getColor(MessageType messageType){
  if(messageType == MessageType.success) {
    return Colors.blue;
  } else if (messageType == MessageType.warn) {
    return Colors.blueGrey;
  } else if (messageType == MessageType.info) {
    return Colors.black87;
  } else if (messageType == MessageType.error) {
    return Colors.red;
  }
  return Colors.blue;
}

IconData getIcon(MessageType messageType){
  if(messageType == MessageType.success) {
    return Icons.check_circle;
  } else if (messageType == MessageType.warn) {
    return Icons.warning;
  } else if (messageType == MessageType.info) {
    return Icons.info;
  } else if (messageType == MessageType.error) {
    return Icons.error;
  }
  return Icons.check_circle;
}

enum MessageType{
  success,
  warn,
  info,
  error
}